==> shortcountrynames-0.5.4-py2.py3-none-any.whl: shortcountrynames/__init__.py <==
"""
shortcountrynames
-----------------

from ._version import get_versions
__version__ = get_versions()['version']
del get_versions

"""


names = {}

names["AFG"] = names["AF"] = "Afghanistan"
names["ALB"] = names["AL"] = "Albania"
names["DZA"] = names["DZ"] = "Algeria"
names["ASM"] = names["AS"] = "American Samoa"
names["AND"] = names["AD"] = "Andorra"
names["AGO"] = names["AO"] = "Angola"
names["AIA"] = names["AI"] = "Anguilla"
names["ATA"] = names["AQ"] = "Antarctica"
names["ATG"] = names["AG"] = "Antigua & Barbuda"
names["ARG"] = names["AR"] = "Argentina"
names["ARM"] = names["AM"] = "Armenia"
names["ABW"] = names["AW"] = "Aruba"
names["AUS"] = names["AU"] = "Australia"
names["AUT"] = names["AT"] = "Austria"
names["AZE"] = names["AZ"] = "Azerbaijan"
names["BHS"] = names["BS"] = "Bahamas"
names["BHR"] = names["BH"] = "Bahrain"
names["BGD"] = names["BD"] = "Bangladesh"
names["BRB"] = names["BB"] = "Barbados"
names["BLR"] = names["BY"] = "Belarus"
names["BEL"] = names["BE"] = "Belgium"
names["BLZ"] = names["BZ"] = "Belize"
names["BEN"] = names["BJ"] = "Benin"
names["BMU"] = names["BM"] = "Bermuda"
names["BTN"] = names["BT"] = "Bhutan"
names["BOL"] = names["BO"] = "Bolivia"
names["BIH"] = names["BA"] = "Bosnia & Herzegovina"
names["BWA"] = names["BW"] = "Botswana"
names["BVT"] = names["BV"] = "Bouvet Island"
names["BRA"] = names["BR"] = "Brazil"
names["IOT"] = names["IO"] = "British Indian Ocean Territory"
names["VGB"] = names["VG"] = "British Virgin Islands"
names["BRN"] = names["BN"] = "Brunei"
names["BGR"] = names["BG"] = "Bulgaria"
names["BFA"] = names["BF"] = "Burkina Faso"
names["BDI"] = names["BI"] = "Burundi"
names["CPV"] = names["CV"] = "Cabo Verde"
names["KHM"] = names["KH"] = "Cambodia"
names["CMR"] = names["CM"] = "Cameroon"
names["CAN"] = names["CA"] = "Canada"
names["BES"] = names["BQ"] = "Caribbean Netherlands"
names["CYM"] = names["KY"] = "Cayman Islands"
names["CAF"] = names["CF"] = "Central African Republic"
names["TCD"] = names["TD"] = "Chad"
names["CHL"] = names["CL"] = "Chile"
names["CHN"] = names["CN"] = "China"
names["CXR"] = names["CX"] = "Christmas Island"
names["CCK"] = names["CC"] = "Cocos (Keeling) Islands"
names["COL"] = names["CO"] = "Colombia"
names["COM"] = names["KM"] = "Comoros"
names["COK"] = names["CK"] = "Cook Islands"
names["CRI"] = names["CR"] = "Costa Rica"
names["HRV"] = names["HR"] = "Croatia"
names["CUB"] = names["CU"] = "Cuba"
names["CUW"] = names["CW"] = "Curaçao"
names["CYP"] = names["CY"] = "Cyprus"
names["CZE"] = names["CZ"] = "Czechia"
names["CIV"] = names["CI"] = "Côte d’Ivoire"
names["COD"] = names["CD"] = "DR Congo"
names["DNK"] = names["DK"] = "Denmark"
names["DJI"] = names["DJ"] = "Djibouti"
names["DMA"] = names["DM"] = "Dominica"
names["DOM"] = names["DO"] = "Dominican Republic"
names["ECU"] = names["EC"] = "Ecuador"
names["EGY"] = names["EG"] = "Egypt"
names["SLV"] = names["SV"] = "El Salvador"
names["GNQ"] = names["GQ"] = "Equatorial Guinea"
names["ERI"] = names["ER"] = "Eritrea"
names["EST"] = names["EE"] = "Estonia"
names["ETH"] = names["ET"] = "Ethiopia"
names["EUU"] = names["EU"] = "European Union"
names["FLK"] = names["FK"] = "Falkland Islands"
names["FRO"] = names["FO"] = "Faroe Islands"
names["FJI"] = names["FJ"] = "Fiji"
names["FIN"] = names["FI"] = "Finland"
names["FRA"] = names["FR"] = "France"
names["GUF"] = names["GF"] = "French Guiana"
names["PYF"] = names["PF"] = "French Polynesia"
names["ATF"] = names["TF"] = "French Southern Territories"
names["GAB"] = names["GA"] = "Gabon"
names["GMB"] = names["GM"] = "Gambia"
names["GEO"] = names["GE"] = "Georgia"
names["DEU"] = names["DE"] = "Germany"
names["GHA"] = names["GH"] = "Ghana"
names["GIB"] = names["GI"] = "Gibraltar"
names["GRC"] = names["GR"] = "Greece"
names["GRL"] = names["GL"] = "Greenland"
names["GRD"] = names["GD"] = "Grenada"
names["GLP"] = names["GP"] = "Guadeloupe"
names["GUM"] = names["GU"] = "Guam"
names["GTM"] = names["GT"] = "Guatemala"
names["GGY"] = names["GG"] = "Guernsey"
names["GIN"] = names["GN"] = "Guinea"
names["GNB"] = names["GW"] = "Guinea-Bissau"
names["GUY"] = names["GY"] = "Guyana"
names["HTI"] = names["HT"] = "Haiti"
names["HMD"] = names["HM"] = "Heard & McDonald Islands"
names["HND"] = names["HN"] = "Honduras"
names["HKG"] = names["HK"] = "Hong Kong"
names["HUN"] = names["HU"] = "Hungary"
names["ISL"] = names["IS"] = "Iceland"
names["IND"] = names["IN"] = "India"
names["IDN"] = names["ID"] = "Indonesia"
names["IRN"] = names["IR"] = "Iran"
names["IRQ"] = names["IQ"] = "Iraq"
names["IRL"] = names["IE"] = "Ireland"
names["IMN"] = names["IM"] = "Isle of Man"
names["ISR"] = names["IL"] = "Israel"
names["ITA"] = names["IT"] = "Italy"
names["JAM"] = names["JM"] = "Jamaica"
names["JPN"] = names["JP"] = "Japan"
names["JEY"] = names["JE"] = "Jersey"
names["JOR"] = names["JO"] = "Jordan"
names["KAZ"] = names["KZ"] = "Kazakhstan"
names["KEN"] = names["KE"] = "Kenya"
names["KIR"] = names["KI"] = "Kiribati"
names["XKX"] = names["XK"] = "Kosovo"
names["KWT"] = names["KW"] = "Kuwait"
names["KGZ"] = names["KG"] = "Kyrgyzstan"
names["LAO"] = names["LA"] = "Laos"
names["LVA"] = names["LV"] = "Latvia"
names["LBN"] = names["LB"] = "Lebanon"
names["LSO"] = names["LS"] = "Lesotho"
names["LBR"] = names["LR"] = "Liberia"
names["LBY"] = names["LY"] = "Libya"
names["LIE"] = names["LI"] = "Liechtenstein"
names["LTU"] = names["LT"] = "Lithuania"
names["LUX"] = names["LU"] = "Luxembourg"
names["MAC"] = names["MO"] = "Macau"
names["MKD"] = names["MK"] = "Macedonia"
names["MDG"] = names["MG"] = "Madagascar"
names["MWI"] = names["MW"] = "Malawi"
names["MYS"] = names["MY"] = "Malaysia"
names["MDV"] = names["MV"] = "Maldives"
names["MLI"] = names["ML"] = "Mali"
names["MLT"] = names["MT"] = "Malta"
names["MHL"] = names["MH"] = "Marshall Islands"
names["MTQ"] = names["MQ"] = "Martinique"
names["MRT"] = names["MR"] = "Mauritania"
names["MUS"] = names["MU"] = "Mauritius"
names["MYT"] = names["YT"] = "Mayotte"
names["MEX"] = names["MX"] = "Mexico"
names["FSM"] = names["FM"] = "Micronesia"
names["MDA"] = names["MD"] = "Moldova"
names["MCO"] = names["MC"] = "Monaco"
names["MNG"] = names["MN"] = "Mongolia"
names["MNE"] = names["ME"] = "Montenegro"
names["MSR"] = names["MS"] = "Montserrat"
names["MAR"] = names["MA"] = "Morocco"
names["MOZ"] = names["MZ"] = "Mozambique"
names["MMR"] = names["MM"] = "Myanmar"
names["NAM"] = names["NA"] = "Namibia"
names["NRU"] = names["NR"] = "Nauru"
names["NPL"] = names["NP"] = "Nepal"
names["NLD"] = names["NL"] = "Netherlands"
names["NCL"] = names["NC"] = "New Caledonia"
names["NZL"] = names["NZ"] = "New Zealand"
names["NIC"] = names["NI"] = "Nicaragua"
names["NER"] = names["NE"] = "Niger"
names["NGA"] = names["NG"] = "Nigeria"
names["NIU"] = names["NU"] = "Niue"
names["NFK"] = names["NF"] = "Norfolk Island"
names["PRK"] = names["KP"] = "North Korea"
names["MNP"] = names["MP"] = "Northern Mariana Islands"
names["NOR"] = names["NO"] = "Norway"
names["OMN"] = names["OM"] = "Oman"
names["PAK"] = names["PK"] = "Pakistan"
names["PLW"] = names["PW"] = "Palau"
names["PSE"] = names["PS"] = "Palestine"
names["PAN"] = names["PA"] = "Panama"
names["PNG"] = names["PG"] = "Papua New Guinea"
names["PRY"] = names["PY"] = "Paraguay"
names["PER"] = names["PE"] = "Peru"
names["PHL"] = names["PH"] = "Philippines"
names["PCN"] = names["PN"] = "Pitcairn Islands"
names["POL"] = names["PL"] = "Poland"
names["PRT"] = names["PT"] = "Portugal"
names["PRI"] = names["PR"] = "Puerto Rico"
names["QAT"] = names["QA"] = "Qatar"
names["COG"] = names["CG"] = "Republic of the Congo"
names["ROU"] = names["RO"] = "Romania"
names["RUS"] = names["RU"] = "Russia"
names["RWA"] = names["RW"] = "Rwanda"
names["REU"] = names["RE"] = "Réunion"
names["WSM"] = names["WS"] = "Samoa"
names["SMR"] = names["SM"] = "San Marino"
names["SAU"] = names["SA"] = "Saudi Arabia"
names["SEN"] = names["SN"] = "Senegal"
names["SRB"] = names["RS"] = "Serbia"
names["SYC"] = names["SC"] = "Seychelles"
names["SLE"] = names["SL"] = "Sierra Leone"
names["SGP"] = names["SG"] = "Singapore"
names["SXM"] = names["SX"] = "Sint Maarten"
names["SVK"] = names["SK"] = "Slovakia"
names["SVN"] = names["SI"] = "Slovenia"
names["SLB"] = names["SB"] = "Solomon Islands"
names["SOM"] = names["SO"] = "Somalia"
names["ZAF"] = names["ZA"] = "South Africa"
names["SGS"] = names["GS"] = "South Georgia & South Sandwich Islands"
names["KOR"] = names["KR"] = "South Korea"
names["SSD"] = names["SS"] = "South Sudan"
names["ESP"] = names["ES"] = "Spain"
names["LKA"] = names["LK"] = "Sri Lanka"
names["BLM"] = names["BL"] = "St. Barthélemy"
names["SHN"] = names["SH"] = "St. Helena"
names["KNA"] = names["KN"] = "St. Kitts & Nevis"
names["LCA"] = names["LC"] = "St. Lucia"
names["MAF"] = names["MF"] = "St. Martin"
names["SPM"] = names["PM"] = "St. Pierre & Miquelon"
names["VCT"] = names["VC"] = "St. Vincent & Grenadines"
names["SDN"] = names["SD"] = "Sudan"
names["SUR"] = names["SR"] = "Suriname"
names["SJM"] = names["SJ"] = "Svalbard & Jan Mayen"
names["SWZ"] = names["SZ"] = "Swaziland"
names["SWE"] = names["SE"] = "Sweden"
names["CHE"] = names["CH"] = "Switzerland"
names["SYR"] = names["SY"] = "Syria"
names["STP"] = names["ST"] = "São Tomé & Príncipe"
names["TWN"] = names["TW"] = "Taiwan"
names["TJK"] = names["TJ"] = "Tajikistan"
names["TZA"] = names["TZ"] = "Tanzania"
names["THA"] = names["TH"] = "Thailand"
names["TLS"] = names["TL"] = "Timor-Leste"
names["TGO"] = names["TG"] = "Togo"
names["TKL"] = names["TK"] = "Tokelau"
names["TON"] = names["TO"] = "Tonga"
names["TTO"] = names["TT"] = "Trinidad & Tobago"
names["TUN"] = names["TN"] = "Tunisia"
names["TUR"] = names["TR"] = "Turkey"
names["TKM"] = names["TM"] = "Turkmenistan"
names["TCA"] = names["TC"] = "Turks & Caicos Islands"
names["TUV"] = names["TV"] = "Tuvalu"
names["UMI"] = names["UM"] = "U.S. Outlying Islands"
names["VIR"] = names["VI"] = "U.S. Virgin Islands"
names["UGA"] = names["UG"] = "Uganda"
names["UKR"] = names["UA"] = "Ukraine"
names["ARE"] = names["AE"] = "United Arab Emirates"
names["GBR"] = names["GB"] = "United Kingdom"
names["USA"] = names["US"] = "United States"
names["URY"] = names["UY"] = "Uruguay"
names["UZB"] = names["UZ"] = "Uzbekistan"
names["VUT"] = names["VU"] = "Vanuatu"
names["VAT"] = names["VA"] = "Vatican City"
names["VEN"] = names["VE"] = "Venezuela"
names["VNM"] = names["VN"] = "Vietnam"
names["WLF"] = names["WF"] = "Wallis & Futuna"
names["ESH"] = names["EH"] = "Western Sahara"
names["YEM"] = names["YE"] = "Yemen"
names["ZMB"] = names["ZM"] = "Zambia"
names["ZWE"] = names["ZW"] = "Zimbabwe"
names["ALA"] = names["AX"] = "Åland Islands"


def to_name(code):
    """Return short name for two or three letter code `code`.

    Non-standard codes: EU and EUU for European Union, XK and XKX for Kosovo"""
    return names[code]

==> shortcountrynames-0.8.0-py2.py3-none-any.whl: shortcountrynames/__init__.py <==
"""
shortcountrynames
-----------------

from ._version import get_versions
__version__ = get_versions()['version']
del get_versions

"""


names = {}

names["AFG"] = names["AF"] = "Afghanistan"
names["ALB"] = names["AL"] = "Albania"
names["DZA"] = names["DZ"] = "Algeria"
names["ASM"] = names["AS"] = "American Samoa"
names["AND"] = names["AD"] = "Andorra"
names["AGO"] = names["AO"] = "Angola"
names["AIA"] = names["AI"] = "Anguilla"
names["ATA"] = names["AQ"] = "Antarctica"
names["ATG"] = names["AG"] = "Antigua & Barbuda"
names["ARG"] = names["AR"] = "Argentina"
names["ARM"] = names["AM"] = "Armenia"
names["ABW"] = names["AW"] = "Aruba"
names["AUS"] = names["AU"] = "Australia"
names["AUT"] = names["AT"] = "Austria"
names["AZE"] = names["AZ"] = "Azerbaijan"
names["BHS"] = names["BS"] = "Bahamas"
names["BHR"] = names["BH"] = "Bahrain"
names["BGD"] = names["BD"] = "Bangladesh"
names["BRB"] = names["BB"] = "Barbados"
names["BLR"] = names["BY"] = "Belarus"
names["BEL"] = names["BE"] = "Belgium"
names["BLZ"] = names["BZ"] = "Belize"
names["BEN"] = names["BJ"] = "Benin"
names["BMU"] = names["BM"] = "Bermuda"
names["BTN"] = names["BT"] = "Bhutan"
names["BOL"] = names["BO"] = "Bolivia"
names["BIH"] = names["BA"] = "Bosnia & Herzegovina"
names["BWA"] = names["BW"] = "Botswana"
names["BVT"] = names["BV"] = "Bouvet Island"
names["BRA"] = names["BR"] = "Brazil"
names["IOT"] = names["IO"] = "British Indian Ocean Territory"
names["VGB"] = names["VG"] = "British Virgin Islands"
names["BRN"] = names["BN"] = "Brunei"
names["BGR"] = names["BG"] = "Bulgaria"
names["BFA"] = names["BF"] = "Burkina Faso"
names["BDI"] = names["BI"] = "Burundi"
names["CPV"] = names["CV"] = "Cabo Verde"
names["KHM"] = names["KH"] = "Cambodia"
names["CMR"] = names["CM"] = "Cameroon"
names["CAN"] = names["CA"] = "Canada"
names["BES"] = names["BQ"] = "Caribbean Netherlands"
names["CYM"] = names["KY"] = "Cayman Islands"
names["CAF"] = names["CF"] = "Central African Republic"
names["TCD"] = names["TD"] = "Chad"
names["CHL"] = names["CL"] = "Chile"
names["CHN"] = names["CN"] = "China"
names["CXR"] = names["CX"] = "Christmas Island"
names["CCK"] = names["CC"] = "Cocos (Keeling) Islands"
names["COL"] = names["CO"] = "Colombia"
names["COM"] = names["KM"] = "Comoros"
names["COK"] = names["CK"] = "Cook Islands"
names["CRI"] = names["CR"] = "Costa Rica"
names["HRV"] = names["HR"] = "Croatia"
names["CUB"] = names["CU"] = "Cuba"
names["CUW"] = names["CW"] = "Curaçao"
names["CYP"] = names["CY"] = "Cyprus"
names["CZE"] = names["CZ"] = "Czechia"
names["CIV"] = names["CI"] = "Côte d’Ivoire"
names["COD"] = names["CD"] = "DR Congo"
names["DNK"] = names["DK"] = "Denmark"
names["DJI"] = names["DJ"] = "Djibouti"
names["DMA"] = names["DM"] = "Dominica"
names["DOM"] = names["DO"] = "Dominican Republic"
names["ECU"] = names["EC"] = "Ecuador"
names["EGY"] = names["EG"] = "Egypt"
names["SLV"] = names["SV"] = "El Salvador"
names["GNQ"] = names["GQ"] = "Equatorial Guinea"
names["ERI"] = names["ER"] = "Eritrea"
names["EST"] = names["EE"] = "Estonia"
names["ETH"] = names["ET"] = "Ethiopia"
names["EUU"] = names["EU"] = "European Union"
names["FLK"] = names["FK"] = "Falkland Islands"
names["FRO"] = names["FO"] = "Faroe Islands"
names["FJI"] = names["FJ"] = "Fiji"
names["FIN"] = names["FI"] = "Finland"
names["FRA"] = names["FR"] = "France"
names["GUF"] = names["GF"] = "French Guiana"
names["PYF"] = names["PF"] = "French Polynesia"
names["ATF"] = names["TF"] = "French Southern Territories"
names["GAB"] = names["GA"] = "Gabon"
names["GMB"] = names["GM"] = "Gambia"
names["GEO"] = names["GE"] = "Georgia"
names["DEU"] = names["DE"] = "Germany"
names["GHA"] = names["GH"] = "Ghana"
names["GIB"] = names["GI"] = "Gibraltar"
names["GRC"] = names["GR"] = "Greece"
names["GRL"] = names["GL"] = "Greenland"
names["GRD"] = names["GD"] = "Grenada"
names["GLP"] = names["GP"] = "Guadeloupe"
names["GUM"] = names["GU"] = "Guam"
names["GTM"] = names["GT"] = "Guatemala"
names["GGY"] = names["GG"] = "Guernsey"
names["GIN"] = names["GN"] = "Guinea"
names["GNB"] = names["GW"] = "Guinea-Bissau"
names["GUY"] = names["GY"] = "Guyana"
names["HTI"] = names["HT"] = "Haiti"
names["HMD"] = names["HM"] = "Heard & McDonald Islands"
names["HND"] = names["HN"] = "Honduras"
names["HKG"] = names["HK"] = "Hong Kong"
names["HUN"] = names["HU"] = "Hungary"
names["ISL"] = names["IS"] = "Iceland"
names["IND"] = names["IN"] = "India"
names["IDN"] = names["ID"] = "Indonesia"
names["IRN"] = names["IR"] = "Iran"
names["IRQ"] = names["IQ"] = "Iraq"
names["IRL"] = names["IE"] = "Ireland"
names["IMN"] = names["IM"] = "Isle of Man"
names["ISR"] = names["IL"] = "Israel"
names["ITA"] = names["IT"] = "Italy"
names["JAM"] = names["JM"] = "Jamaica"
names["JPN"] = names["JP"] = "Japan"
names["JEY"] = names["JE"] = "Jersey"
names["JOR"] = names["JO"] = "Jordan"
names["KAZ"] = names["KZ"] = "Kazakhstan"
names["KEN"] = names["KE"] = "Kenya"
names["KIR"] = names["KI"] = "Kiribati"
names["XKX"] = names["XK"] = "Kosovo"
names["KWT"] = names["KW"] = "Kuwait"
names["KGZ"] = names["KG"] = "Kyrgyzstan"
names["LAO"] = names["LA"] = "Laos"
names["LVA"] = names["LV"] = "Latvia"
names["LBN"] = names["LB"] = "Lebanon"
names["LSO"] = names["LS"] = "Lesotho"
names["LBR"] = names["LR"] = "Liberia"
names["LBY"] = names["LY"] = "Libya"
names["LIE"] = names["LI"] = "Liechtenstein"
names["LTU"] = names["LT"] = "Lithuania"
names["LUX"] = names["LU"] = "Luxembourg"
names["MAC"] = names["MO"] = "Macau"
names["MKD"] = names["MK"] = "North Macedonia"
names["MDG"] = names["MG"] = "Madagascar"
names["MWI"] = names["MW"] = "Malawi"
names["MYS"] = names["MY"] = "Malaysia"
names["MDV"] = names["MV"] = "Maldives"
names["MLI"] = names["ML"] = "Mali"
names["MLT"] = names["MT"] = "Malta"
names["MHL"] = names["MH"] = "Marshall Islands"
names["MTQ"] = names["MQ"] = "Martinique"
names["MRT"] = names["MR"] = "Mauritania"
names["MUS"] = names["MU"] = "Mauritius"
names["MYT"] = names["YT"] = "Mayotte"
names["MEX"] = names["MX"] = "Mexico"
names["FSM"] = names["FM"] = "Micronesia"
names["MDA"] = names["MD"] = "Moldova"
names["MCO"] = names["MC"] = "Monaco"
names["MNG"] = names["MN"] = "Mongolia"
names["MNE"] = names["ME"] = "Montenegro"
names["MSR"] = names["MS"] = "Montserrat"
names["MAR"] = names["MA"] = "Morocco"
names["MOZ"] = names["MZ"] = "Mozambique"
names["MMR"] = names["MM"] = "Myanmar"
names["NAM"] = names["NA"] = "Namibia"
names["NRU"] = names["NR"] = "Nauru"
names["NPL"] = names["NP"] = "Nepal"
names["NLD"] = names["NL"] = "Netherlands"
names["NCL"] = names["NC"] = "New Caledonia"
names["NZL"] = names["NZ"] = "New Zealand"
names["NIC"] = names["NI"] = "Nicaragua"
names["NER"] = names["NE"] = "Niger"
names["NGA"] = names["NG"] = "Nigeria"
names["NIU"] = names["NU"] = "Niue"
names["NFK"] = names["NF"] = "Norfolk Island"
names["PRK"] = names["KP"] = "North Korea"
names["MNP"] = names["MP"] = "Northern Mariana Islands"
names["NOR"] = names["NO"] = "Norway"
names["OMN"] = names["OM"] = "Oman"
names["PAK"] = names["PK"] = "Pakistan"
names["PLW"] = names["PW"] = "Palau"
names["PSE"] = names["PS"] = "Palestine"
names["PAN"] = names["PA"] = "Panama"
names["PNG"] = names["PG"] = "Papua New Guinea"
names["PRY"] = names["PY"] = "Paraguay"
names["PER"] = names["PE"] = "Peru"
names["PHL"] = names["PH"] = "Philippines"
names["PCN"] = names["PN"] = "Pitcairn Islands"
names["POL"] = names["PL"] = "Poland"
names["PRT"] = names["PT"] = "Portugal"
names["PRI"] = names["PR"] = "Puerto Rico"
names["QAT"] = names["QA"] = "Qatar"
names["COG"] = names["CG"] = "Republic of the Congo"
names["ROU"] = names["RO"] = "Romania"
names["RUS"] = names["RU"] = "Russia"
names["RWA"] = names["RW"] = "Rwanda"
names["REU"] = names["RE"] = "Réunion"
names["WSM"] = names["WS"] = "Samoa"
names["SMR"] = names["SM"] = "San Marino"
names["SAU"] = names["SA"] = "Saudi Arabia"
names["SEN"] = names["SN"] = "Senegal"
names["SRB"] = names["RS"] = "Serbia"
names["SYC"] = names["SC"] = "Seychelles"
names["SLE"] = names["SL"] = "Sierra Leone"
names["SGP"] = names["SG"] = "Singapore"
names["SXM"] = names["SX"] = "Sint Maarten"
names["SVK"] = names["SK"] = "Slovakia"
names["SVN"] = names["SI"] = "Slovenia"
names["SLB"] = names["SB"] = "Solomon Islands"
names["SOM"] = names["SO"] = "Somalia"
names["ZAF"] = names["ZA"] = "South Africa"
names["SGS"] = names["GS"] = "South Georgia & South Sandwich Islands"
names["KOR"] = names["KR"] = "South Korea"
names["SSD"] = names["SS"] = "South Sudan"
names["ESP"] = names["ES"] = "Spain"
names["LKA"] = names["LK"] = "Sri Lanka"
names["BLM"] = names["BL"] = "St. Barthélemy"
names["SHN"] = names["SH"] = "St. Helena"
names["KNA"] = names["KN"] = "St. Kitts & Nevis"
names["LCA"] = names["LC"] = "St. Lucia"
names["MAF"] = names["MF"] = "St. Martin"
names["SPM"] = names["PM"] = "St. Pierre & Miquelon"
names["VCT"] = names["VC"] = "St. Vincent & Grenadines"
names["SDN"] = names["SD"] = "Sudan"
names["SUR"] = names["SR"] = "Suriname"
names["SJM"] = names["SJ"] = "Svalbard & Jan Mayen"
names["SWZ"] = names["SZ"] = "Eswatini"
names["SWE"] = names["SE"] = "Sweden"
names["CHE"] = names["CH"] = "Switzerland"
names["SYR"] = names["SY"] = "Syria"
names["STP"] = names["ST"] = "São Tomé & Príncipe"
names["TWN"] = names["TW"] = "Taiwan"
names["TJK"] = names["TJ"] = "Tajikistan"
names["TZA"] = names["TZ"] = "Tanzania"
names["THA"] = names["TH"] = "Thailand"
names["TLS"] = names["TL"] = "Timor-Leste"
names["TGO"] = names["TG"] = "Togo"
names["TKL"] = names["TK"] = "Tokelau"
names["TON"] = names["TO"] = "Tonga"
names["TTO"] = names["TT"] = "Trinidad & Tobago"
names["TUN"] = names["TN"] = "Tunisia"
names["TUR"] = names["TR"] = "Turkey"
names["TKM"] = names["TM"] = "Turkmenistan"
names["TCA"] = names["TC"] = "Turks & Caicos Islands"
names["TUV"] = names["TV"] = "Tuvalu"
names["UMI"] = names["UM"] = "U.S. Outlying Islands"
names["VIR"] = names["VI"] = "U.S. Virgin Islands"
names["UGA"] = names["UG"] = "Uganda"
names["UKR"] = names["UA"] = "Ukraine"
names["ARE"] = names["AE"] = "United Arab Emirates"
names["GBR"] = names["GB"] = "United Kingdom"
names["USA"] = names["US"] = "USA"
names["URY"] = names["UY"] = "Uruguay"
names["UZB"] = names["UZ"] = "Uzbekistan"
names["VUT"] = names["VU"] = "Vanuatu"
names["VAT"] = names["VA"] = "Vatican City"
names["VEN"] = names["VE"] = "Venezuela"
names["VNM"] = names["VN"] = "Vietnam"
names["WLF"] = names["WF"] = "Wallis & Futuna"
names["ESH"] = names["EH"] = "Western Sahara"
names["YEM"] = names["YE"] = "Yemen"
names["ZMB"] = names["ZM"] = "Zambia"
names["ZWE"] = names["ZW"] = "Zimbabwe"
names["ALA"] = names["AX"] = "Åland Islands"


def to_name(code):
    """Return short name for two or three letter code `code`.

    Non-standard codes: EU and EUU for European Union, XK and XKX for Kosovo"""
    return names[code]
